@@ -1,3 +1,5 @@
+import base64
+from distutils.ccompiler import gen_lib_options
 import logging
 from os import path
 from test.common.utilities import dict_compare_keys, get_sample_file_path
@@ -51,16 +53,28 @@ def test_generate_file_urls(fyle, mock_data):
     upload_url = generate_file_urls["data"]["upload_url"]
     assert dict_compare_keys(generate_file_urls["data"], mock_files) == [], 'response from fyle.v1beta.spender.files.create_file() has stuff that mock_data doesnt'
     assert dict_compare_keys(mock_files, generate_file_urls["data"]) == [], 'mock_data.file_generate_url.get() has stuff that fyle doesnt'
-  
 
 def test_put_file_to_url(fyle):
   basepath = get_sample_file_path()
   file_path = path.join(basepath, 'sample.jpg')
+  with open(file_path, "rb") as image_file:
+    file_data = base64.b64encode(image_file.read())
+
+  put_file_to_url = fyle.v1beta.spender.files.put_file_to_url(
+    content_type="image/jpeg", url=upload_url,
+    data=file_data
+  )
+  assert put_file_to_url == True
+
+
+def test_put_file_to_url_invalid_file(fyle):
+  basepath = get_sample_file_path()
+  file_path = path.join(basepath, 'uber_expenses_2.txt')
   file_data = open(file_path, 'rb')
 
   try:
     put_file_to_url = fyle.v1beta.spender.files.put_file_to_url(
-      content_type="text/csv", url=upload_url,
+      content_type="image/jpeg", url=upload_url,
       data=file_data
     )
   except:
@@ -87,7 +101,7 @@ def test_attach_receipt(fyle, mock_data):
   attach_receipt = fyle.v1beta.spender.expenses.attach_receipt(payload = {
     "data": {
       "id": expense_id,
-      "file_id": 'fi0Wa1GHhcwi'
+      "file_id": file_id
     }
   })
   mock_files = mock_data.attach_receipt.get()
